@@ -11,7 +11,7 @@ test_that("Import from SAS (.xpt)", {
 })
 
 test_that("Export SAS (.sas7bdat)", {
-    expect_true(export(mtcars, "mtcars.sas7bdat") %in% dir())
+    expect_true(suppressWarnings(export(mtcars, "mtcars.sas7bdat")) %in% dir())
 })
 
 unlink("mtcars.sas7bdat")
